"""
Primitive atomic and molecular objects for pygamlab.
"""
from .gam_universe import GAM_Atom
from .gam_universe import GAM_Bond
from .gam_molecule import GAM_Molecule



__all__ = ['GAM_Atom', 'GAM_Bond', 'GAM_Molecule']
